import re
import sys
import time

import Parser
import util

class ParserRealSecure(Parser.Parser):

    eventEntryNames = [ 
        '6in4_Tunnel',
        'AIX_Pdnsd_Overflow',
        'AOLIM_AddExternalApp_Overflow',
        'AOLIM_File_Xfer',
        'AOLIM_GameRequest_Overflow',
        'AOLIM_Login',
        'AOLIM_Message',
        'AOLIM_Password_Change',
        'AOLIM_Trillian_Encrypt_Handshake',
        'AOL_Instant_Messenger_Overflow',
        'ASP_Chunked_Overflow',
        'AUDIT_DNS_Version_Request',
        'Account_policy_change',
        'Add_SID_failure',
        'Add_SID_success',
        'Allaire_JRun_JSP_Execute',
        'Allaire_JRun_SSIFilter',
        'Allaire_JRun_Sample_Files',
        'Allaire_JRun_WebInf_DotSlash',
        'Allaire_JRun_WebInf_SlashSlash',
        'AntiSniff_ARP_Test',
        'AntiSniff_DNS_Test',
        'AolAdmin_Response',
        'Ascend_Kill',
        'Ascend_Kill_II',
        'Asylum_Response',
        'Audit_TFTP_Get_Filename',
        'Audit_log_cleared',
        'Audit_policy_change',
        'Authentication_package_loaded',
        'Authentication_ticket_granted',
        'Authentication_ticket_request_failed',
        'Avaya_Cajun_Default_SNMP',
        'BGP_Illegal_Size',
        'BGP_New_Route',
        'BGP_Notify_Msg',
        'BGP_Route_Unreachable',
        'BOOTP_Remote_Overflow',
        'BackConstruction_Response',
        'BackOrifice2K_TCP_Auth_Request',
        'BackOrifice2K_TCP_Auth_Response',
        'BackOrifice2K_TCP_Request',
        'BackOrifice2K_TCP_Response',
        'BackOrifice2K_UDP_Auth_Request',
        'BackOrifice2K_UDP_Auth_Response',
        'BackOrifice2K_UDP_Request',
        'BackOrifice2K_UDP_Response',
        'BackOrifice_Ping',
        'BackOrifice_Request',
        'BackOrifice_Response',
        'Backdoor2_Response',
        'BigGluck_Response',
        'BioNet_Response',
        'BitTorrent_Get_Request',
        'BitTorrent_Response',
        'Blazer5_Response',
        'Boink',
        'Bonk',
        'Bootparam',
        'Brute_force_login_attack',
        'Brute_force_login_likely_successful',
        'Bugs_Response',
        'Buschtrommel_TCP_Response',
        'Cerebus_Scanner',
        'Change_password_attack',
        'Change_password_attack_likely_successful',
        'Changes_to_important_files',
        'Chargen_Denial_of_Service',
        'Chupacabra_Request',
        'Cisco_CR_DoS',
        'Cisco_Cable_Docsis_SNMP_Community',
        'Cisco_ILMI_SNMP_Community',
        'Cisco_IOS_IPV4_DoS',
        'Cisco_IOS_OSPF_BO',
        'Cisco_Ident',
        'Coma_Response',
        'Computer_account_changed',
        'Computer_account_created',
        'Computer_account_deleted',
        'Config-log_files_delete_failed',
        'Config-log_files_deleted',
        'ConnectionBackdoor_Response',
        'Corrupt_IP_Options',
        'CrazzyNet_Response',
        'CyberCop_Scanner_HTTP',
        'CyberCop_Scanner_ICMP',
        'CyberCop_Scanner_RPC',
        'CyberCop_Scanner_Radius',
        'CyberCop_Scanner_SMTP',
        'CyberCop_Scanner_TFTP',
        'DCOM_Large_Body_Extension',
        'DCOM_RemoteActivate',
        'DCOM_RemoteGetClassObject_DoS',
        'DCOM_Scada_Opc_Bind',
        'DCOM_Scada_Opc_Bo',
        'DCOM_SystemActivation',
        'DHCP_Ack',
        'DHCP_Discover',
        'DHCP_Domain_Metachar',
        'DHCP_Format_String_BO',
        'DHCP_Minires_Format_Overflow',
        'DHCP_Request',
        'DNS_Address_Length',
        'DNS_Antisniff_Overflow',
        'DNS_Bind_OPT_DoS',
        'DNS_Bind_SIG_Overflow',
        'DNS_Chaos_Request',
        'DNS_Crack_Success',
        'DNS_Excessive_Requests',
        'DNS_Format_String',
        'DNS_Generic_Intel_Overflow',
        'DNS_HInfo',
        'DNS_Hostname_Overflow',
        'DNS_Hostname_Overflow_Verylong',
        'DNS_IQuery',
        'DNS_IQuery_bo',
        'DNS_Malformed',
        'DNS_NULL_Query',
        'DNS_NXT_Overflow',
        'DNS_NonInternet',
        'DNS_Poison',
        'DNS_Query_All',
        'DNS_Spoof_Failed',
        'DNS_Spoof_Success',
        'DNS_TSIG_Overflow',
        'DNS_Version_Request',
        'DNS_VirusScanTrojan',
        'DNS_Zero_Size_UDP',
        'DNS_Zone_Transfer',
        'DNS_Zonexfer_High',
        'DeepThroat_Response',
        'DeltaSource_Response',
        'Devil_Request',
        'Disk_space_shortage',
        'Doly_Response',
        'DonaldDick_Response',
        'Dtspcd_Overflow',
        'EMail_Generic_Intel_Overflow',
        'EPolicy_Orchestrator_Format_String',
        'Echo_Denial_of_Service',
        'Echo_Reply_Without_Request',
        'Email_Almail_Overflow',
        'Email_Amavis_Exec',
        'Email_Auth_Failed',
        'Email_Auth_Overflow',
        'Email_BioNet',
        'Email_Command_Overflow',
        'Email_Data',
        'Email_Debug',
        'Email_Decode',
        'Email_Ehlo',
        'Email_Encap_Exch_Relay',
        'Email_Encap_Relay',
        'Email_Envid_Overflow',
        'Email_Error',
        'Email_ExchangeStore_DoS',
        'Email_Expn',
        'Email_Expn_Overflow',
        'Email_False_Attachment',
        'Email_From',
        'Email_From_Overflow',
        'Email_Helo_Overflow',
        'Email_IE_HRAlign_Overflow',
        'Email_IE_ObjectType_Overflow',
        'Email_Invalid_Command',
        'Email_Listserv_Overflow',
        'Email_Lotus_Domino',
        'Email_Mime_Filename',
        'Email_Mime_Filename_Blanks',
        'Email_Mime_Filename_Chars',
        'Email_Mime_Filename_Overflow',
        'Email_Mime_Name_Overflow',
        'Email_Mime_Null',
        'Email_Name_Overflow',
        'Email_Outlook_Date_Overflow',
        'Email_Pipe',
        'Email_Qmail_Length',
        'Email_Qmail_Rcpt',
        'Email_Rcpt_TooManyQuotes',
        'Email_Recipient_Dot',
        'Email_Recipient_Overflow',
        'Email_Relay_Attempt',
        'Email_Relay_Spam',
        'Email_ReplyTo_Executable',
        'Email_Rpmmail_Alias',
        'Email_ServerID',
        'Email_SubSeven',
        'Email_Subject',
        'Email_To',
        'Email_To_Dot_Dot',
        'Email_Turn',
        'Email_UUDecode_Alias',
        'Email_VCF_Overflow',
        'Email_Virus_Double_Extension',
        'Email_Virus_Double_Extension_Block',
        'Email_Virus_Iloveyou',
        'Email_Virus_Melissa',
        'Email_Virus_PICTURE_EXE',
        'Email_Virus_Papa',
        'Email_Virus_exploreZip',
        'Email_Virus_investigator',
        'Email_Vrfy',
        'Email_Vrfy_Overflow',
        'Email_WIZ',
        'Email_Xchg_Auth',
        'Email_Y3K',
        'EventHorizon_Request',
        'EvilFTP_Response',
        'Exchange55_administrator_connect',
        'Exchange55_administrator_login_as_user',
        'Exchange55_pop3_authentication_failures',
        'Exchange55_unauthenticated_pop3_command',
        'Exchange55_unauthenticated_pop3_command_invalid',
        'Exchange55_unauthenticated_pop3_command_invalidargs',
        'Exchange55_unauthenticated_pop3_command_wrongargs',
        'Exchange55_view_administrator_login',
        'Exchange_PST_passwords_saved',
        'Exchange_administrator_connect',
        'Exchange_administrator_login_as_user',
        'Exchange_anonymous_logon',
        'Exchange_imap_authentication_failures',
        'Exchange_logon_failure',
        'Exchange_mail_sent_as',
        'Exchange_mail_sent_on_behalf',
        'Exchange_nntp_authentication_failures',
        'Exchange_pop3_authentication_failures',
        'Exchange_security_attribute_change',
        'Exchange_service_password_change',
        'Exchange_unauthenticated_imap_command',
        'Exchange_unauthenticated_logon_attempt',
        'Exchange_unauthenticated_nntp_command',
        'Exchange_unauthenticated_pop3_command',
        'Exchange_unauthenticated_pop3_command_invalid',
        'Exchange_unauthenticated_pop3_command_invalidargs',
        'Exchange_unauthenticated_pop3_command_wrongargs',
        'Exchange_user_login_into_other_users_mailbox',
        'Exchange_view_administrator_login',
        'Exploiter_TCP_Response',
        'FSP_Delete_File',
        'FSP_Detected',
        'FSP_Read_File',
        'FSP_Write_File',
        'FTP_AIX_Overflow',
        'FTP_Args_Overflow',
        'FTP_Auth_Failed',
        'FTP_Command_Overflow',
        'FTP_Commands_With_Binary',
        'FTP_Cwd_Overflow',
        'FTP_Cwd_Root',
        'FTP_Cwd_Tilde',
        'FTP_Cwd_concon',
        'FTP_Cwd_dotdot',
        'FTP_Cybercop_Scan',
        'FTP_Data_Overflow',
        'FTP_Delete_Very_Long',
        'FTP_Delete_dotdot',
        'FTP_FileName_Bdl',
        'FTP_File_Exec',
        'FTP_Filename',
        'FTP_Filename_Overflow',
        'FTP_Floppy_DoS',
        'FTP_Fname_Eftp2',
        'FTP_Fname_Lnk',
        'FTP_Format_String',
        'FTP_Generic_Intel_Overflow',
        'FTP_Get',
        'FTP_Glob_Expansion',
        'FTP_Glob_Implementation',
        'FTP_Glob_TildeBrace_Vulns',
        'FTP_Help_Overflow',
        'FTP_Invalid_Port_Cmd',
        'FTP_List_dotdot',
        'FTP_Login_Overflow',
        'FTP_Mdtm_Very_Long',
        'FTP_Mget_DotDot',
        'FTP_Mkd_Overflow',
        'FTP_Mkdir',
        'FTP_Mlst_Very_Long',
        'FTP_NLST_Overflow',
        'FTP_NetTerm_Dele_Overflow',
        'FTP_NetTerm_Dir_Overflow',
        'FTP_NetTerm_Ls_Overflow',
        'FTP_NetTerm_Mkd_Overflow',
        'FTP_NetTerm_Pass_Overflow',
        'FTP_NetTerm_Rmdir_Overflow',
        'FTP_Pass',
        'FTP_Passive_Very_Long',
        'FTP_Password_Overflow',
        'FTP_Pasv',
        'FTP_Pasv_DOS',
        'FTP_Pipe',
        'FTP_Port',
        'FTP_Port_Bounce',
        'FTP_Port_Very_Long',
        'FTP_PrivilegedBounce',
        'FTP_PrivilegedPort',
        'FTP_ProFTPD',
        'FTP_ProFTPD_Translate_Overflow',
        'FTP_Put',
        'FTP_Restart_Very_Long',
        'FTP_Retr_Very_Long',
        'FTP_Retr_dotdot',
        'FTP_Rmd_Very_Long',
        'FTP_Rnfr_Very_Long',
        'FTP_Rnto_Very_Long',
        'FTP_Server_Identity',
        'FTP_Site_Chown_Overflow',
        'FTP_Site_Cmd',
        'FTP_Site_Cpwd',
        'FTP_Site_Exec',
        'FTP_Site_Exec_DotDot',
        'FTP_Site_Exec_Tar',
        'FTP_Site_Pswd',
        'FTP_Size_Very_Long',
        'FTP_Size_dotdot',
        'FTP_Stat_Very_Long',
        'FTP_Stor_Very_Long',
        'FTP_Syst',
        'FTP_Tar_Exec',
        'FTP_Unix_Password_File',
        'FTP_Unix_RemoteHost_File',
        'FTP_User',
        'FTP_User_Root',
        'FTP_Virus_Wm_Marker_A',
        'FTP_WUFTP_RealPath_BO',
        'FTP_Wildcard_DoS',
        'FTP_Windows_Drive_Path',
        'FTP_Windows_INI_File',
        'FTP_Windows_PWL_File',
        'FTP_Windows_SAM_File',
        'FTP_ZIPCHK_Meta',
        'FTP_ZIPCHK_Overflow',
        'FTP_dotdotdot',
        'FW1_Auth_As_Local',
        'FW1_Auth_Replay',
        'FW1_GetTopology',
        'Failed_change_of_important_files',
        'Failed_login-account_disabled',
        'Failed_login-account_expired',
        'Failed_login-account_locked_out',
        'Failed_login-bad_username_or_password',
        'Failed_login-net_logon_not_active',
        'Failed_login-not_authorized_for_console_login',
        'Failed_login-not_authorized_for_this_type_of_login',
        'Failed_login-password_expired',
        'Failed_login-time_restriction_violation',
        'Failed_login-unknown_error',
        'FastTrack_Download',
        'Finger_Backdoor',
        'Finger_Command',
        'Finger_Enumeration',
        'Finger_Filename',
        'Finger_Forwarding',
        'Finger_Forwarding_DOS',
        'Finger_Generic_Intel_Overflow',
        'Finger_List',
        'Finger_Overflow',
        'Finger_Overflow_RTM',
        'Finger_Root',
        'Finger_Scan',
        'Finger_Search',
        'Finger_User',
        'ForcedEntry_Response',
        'Fore_Response',
        'FragRoute_TCP_Chaff_PAWS',
        'Fraggle_Attack',
        'Fragment_Differential_Overlap',
        'Fragment_Differential_Size',
        'Fragment_Resources_Exhausted',
        'Freak88_Response',
        'Frenzy_Response',
        'GateCrasher_Response',
        'Gauntlet_CyberDaemon_Overflow',
        'Gauntlet_ICMP_DoS',
        'GayOL_Request',
        'GirlFriend_Response',
        'Glacier_Request',
        'Glacier_Response',
        'Global_group_changed',
        'Global_group_created',
        'Global_group_deleted',
        'Global_group_user_added',
        'Global_group_user_removed',
        'Gnutella_BearShare',
        'Gnutella_Connect',
        'Gnutella_Download',
        'Gnutella_LimeWire',
        'Gnutella_Shareaza',
        'Gnutella_Worm',
        'Group_type_changed',
        'Guest_user_login',
        'HPUX_RLPD_Overflow',
        'HP_OpenView_NNM_Overflow',
        'HP_OpenView_SNMP_Backdoor',
        'HSRP_Coup',
        'HSRP_Default_Password',
        'HSRP_Invalid_IPTTL',
        'HSRP_Resign',
        'HSRP_Suspicious_Priority',
        'HTTP_$DATA_Source_Disclosed',
        'HTTP_3com_AirConnect_EasySetup',
        'HTTP_3com_AirConnect_FilteringSetup',
        'HTTP_3com_AirConnect_FirmwareSetup',
        'HTTP_3com_AirConnect_ModemSetup',
        'HTTP_3com_AirConnect_RFSetup',
        'HTTP_3com_AirConnect_SNMPSetup',
        'HTTP_3com_AirConnect_SecuritySetup',
        'HTTP_3com_AirConnect_SpecialFunctions',
        'HTTP_3com_AirConnect_SystemSetup',
        'HTTP_ACCEPT_Overflow',
        'HTTP_ASP_Stateserver_Overflow',
        'HTTP_ActiveX',
        'HTTP_Adpassword_Text',
        'HTTP_Advancestack_BypassAuth',
        'HTTP_Aglimpse',
        'HTTP_AllaireJrun_ViewDirectory',
        'HTTP_AnswerBook2_Admin',
        'HTTP_AnswerBook2_DocServer',
        'HTTP_AnswerBook2_Execute',
        'HTTP_Answerbook_AddAdmin',
        'HTTP_Answerbook_Format_String',
        'HTTP_AnyForm',
        'HTTP_AnyForm_Post',
        'HTTP_Apache_Chunked_BO',
        'HTTP_Apache_Chunked_DoS',
        'HTTP_Apache_DOS',
        'HTTP_Apache_Jakarta_Format_String',
        'HTTP_Apache_Macros_dir',
        'HTTP_Apache_PHP',
        'HTTP_Apache_SlashSlash',
        'HTTP_Arcadia_Tradecli',
        'HTTP_Auctionweaver',
        'HTTP_AuthFilter_ISAPI_Overflow',
        'HTTP_Auth_Failed',
        'HTTP_Auth_TooLong',
        'HTTP_Authentication',
        'HTTP_Axis_Storpoint',
        'HTTP_BAT_Execute',
        'HTTP_BBN_survey',
        'HTTP_BadBlue_DOS',
        'HTTP_BadBlue_DirDisclosure',
        'HTTP_Bash_Shell_History',
        'HTTP_BigBrother_History',
        'HTTP_Bigsam',
        'HTTP_BioNet_ICQ_Pager',
        'HTTP_BrownOrifice',
        'HTTP_Bugbear_Backdoor',
        'HTTP_CGI_Fastgraf',
        'HTTP_CGI_Guestbook_Generic',
        'HTTP_CGI_Guestbook_Meta',
        'HTTP_CMD_Execute',
        'HTTP_Cachemgr',
        'HTTP_Calender_Admin',
        'HTTP_Campas',
        'HTTP_Carbo_Server',
        'HTTP_Carello',
        'HTTP_Cart32_ChangeAdminPassword',
        'HTTP_Cart32_ClientList',
        'HTTP_Cart32_Expdate',
        'HTTP_Cdomain',
        'HTTP_CgiCounterLong',
        'HTTP_Cgiproc_DoS',
        'HTTP_Cgiproc_File_Read',
        'HTTP_CheckLoginPhp',
        'HTTP_Cisco_Aironet_Webconfig',
        'HTTP_Cisco_Catalyst_Exec',
        'HTTP_Cisco_IOS_Admin_Access',
        'HTTP_Cisco_IOS_DOS',
        'HTTP_Cisco_IOS_Query_DOS',
        'HTTP_Classifieds_Post',
        'HTTP_CobaltRAQ_OverflowCGI',
        'HTTP_CobaltRAQ_alert',
        'HTTP_CobaltRAQ_service',
        'HTTP_Code_Red',
        'HTTP_Code_Red_II',
        'HTTP_Code_Red_II_Plus',
        'HTTP_ColdFusion_Admin',
        'HTTP_ColdFusion_Cfcache',
        'HTTP_ColdFusion_Debug',
        'HTTP_ColdFusion_Email_ExampleApp',
        'HTTP_ColdFusion_Expr_Evaluator',
        'HTTP_ColdFusion_FileExists',
        'HTTP_ColdFusion_RDS_Null_Password',
        'HTTP_ColdFusion_RDS_Password',
        'HTTP_ColdFusion_SourceWindow',
        'HTTP_ColdFusion_SyntaxChecker_DOS',
        'HTTP_ColdFusion_ViewExample',
        'HTTP_ColdFusion_WebPublish_ExampleApp',
        'HTTP_Commerce',
        'HTTP_CompaqInsightManager_Taglist',
        'HTTP_Compaq_Insight_Cpqlogin_Overflow',
        'HTTP_Compaq_Insight_DoS',
        'HTTP_Compaq_Insight_Fileread',
        'HTTP_Compaq_Insight_FormatString',
        'HTTP_Connection_Overflow',
        'HTTP_Cookie',
        'HTTP_Count',
        'HTTP_Cross_Site_Scripting',
        'HTTP_Csvform_Execute',
        'HTTP_DCForum_Admin_Access',
        'HTTP_DCForum_File_Upload',
        'HTTP_DCForum_Traversal',
        'HTTP_DCShop_info',
        'HTTP_Dansie_Backdoor',
        'HTTP_Dansie_Cart',
        'HTTP_Dansie_Infoleak',
        'HTTP_Dir_Manager_exe',
        'HTTP_Domino_Navigator',
        'HTTP_Domino_Web_Access',
        'HTTP_DosDevice',
        'HTTP_DotDot',
        'HTTP_DotDotDot',
        'HTTP_DragonFire',
        'HTTP_ECware_DOS',
        'HTTP_EDonkey',
        'HTTP_EPerl_isindex',
        'HTTP_EZMall_Malllogfile',
        'HTTP_EZShopper_Loadpage',
        'HTTP_EZShopper_Search',
        'HTTP_Empower',
        'HTTP_Eva_Forms_Bo',
        'HTTP_Eva_Forms_Dir',
        'HTTP_Favorites_Icon_Overflow',
        'HTTP_FaxSurvey',
        'HTTP_Field_With_Binary',
        'HTTP_Fields_With_Binary',
        'HTTP_FileTypeLnk',
        'HTTP_FileTypeUrl',
        'HTTP_FingerCgi',
        'HTTP_FormMail',
        'HTTP_FrontPage_Authors',
        'HTTP_FrontPage_DeviceName',
        'HTTP_FrontPage_PWD',
        'HTTP_Frontpage_Extensions_RAD_Overflow',
        'HTTP_Frontpage_Path',
        'HTTP_Frontpage_Publish',
        'HTTP_GET_ComputeSum',
        'HTTP_GET_CreateTable',
        'HTTP_GET_DotDot_Data',
        'HTTP_GET_Dotdotdot_Data',
        'HTTP_GET_Filename_mgtstate',
        'HTTP_GET_Filename_mysql',
        'HTTP_GET_Filename_pwl',
        'HTTP_GET_Filename_sam',
        'HTTP_GET_GroupBy',
        'HTTP_GET_SQL_OpenRowSet',
        'HTTP_GET_SQL_UnionAllSelect',
        'HTTP_GET_SQL_UnionSelect',
        'HTTP_GET_SQL_WaitForDelay',
        'HTTP_GET_Very_Long',
        'HTTP_GET_XP_Cmdshell',
        'HTTP_GETargscript',
        'HTTP_Gator_Installed',
        'HTTP_Generic_Intel_Overflow',
        'HTTP_Get',
        'HTTP_GetAccess_helpwin',
        'HTTP_GetAccess_login',
        'HTTP_GetArg',
        'HTTP_Glimpse',
        'HTTP_GotoMyPCDOTCom_Connection',
        'HTTP_Groupwise_Path',
        'HTTP_Guestbook',
        'HTTP_HOST_Overflow',
        'HTTP_HTDIG_htsearch',
        'HTTP_HTMLScript',
        'HTTP_HackATack_ICQ_Pager',
        'HTTP_Hassan_Execute',
        'HTTP_Head',
        'HTTP_HomeFree_Search',
        'HTTP_HotMail_Email_Attachment',
        'HTTP_Htaccess',
        'HTTP_Htimage_Dir',
        'HTTP_Htimage_Exe',
        'HTTP_Htimage_Files',
        'HTTP_ICQ_Pager',
        'HTTP_IE_HRAlign_Overflow',
        'HTTP_IE_HTML_Embed_Overflow',
        'HTTP_IE_Help_Overflow',
        'HTTP_IE_MHT_Overflow',
        'HTTP_IExplorer_Command_Exec',
        'HTTP_IIS3_Asp_Dot',
        'HTTP_IISExAir_DOS',
        'HTTP_IISHTR_Overflow',
        'HTTP_IIS_ASP_Chunked_Overflow',
        'HTTP_IIS_Bdir_Htr',
        'HTTP_IIS_CmdAsp',
        'HTTP_IIS_Csimple',
        'HTTP_IIS_Device_Asp',
        'HTTP_IIS_Double_Eval_Evasion',
        'HTTP_IIS_HTR_Chunked_Overflow',
        'HTTP_IIS_Hex_Evasion',
        'HTTP_IIS_Host_DoS',
        'HTTP_IIS_ISAPI_Filter_Error_DoS',
        'HTTP_IIS_ISAPI_Nsiislog_Overflow',
        'HTTP_IIS_ISAPI_Printer_Overflow',
        'HTTP_IIS_IndexSearch',
        'HTTP_IIS_Index_Server_Overflow',
        'HTTP_IIS_Invalid_File_Parsing',
        'HTTP_IIS_MSSQL_XML_Script',
        'HTTP_IIS_MSSQL_xml',
        'HTTP_IIS_Many_Hosts',
        'HTTP_IIS_Media_Services',
        'HTTP_IIS_Obtain_Code',
        'HTTP_IIS_Percent_Evasion',
        'HTTP_IIS_Showcode',
        'HTTP_IIS_Trailing_Incomplete_Unicode',
        'HTTP_IIS_Trailing_Slash',
        'HTTP_IIS_UTF8_Evasion',
        'HTTP_IIS_Unicode_Encoding',
        'HTTP_IIS_Unicode_Wide_Encoding',
        'HTTP_IIS_dumpvariables',
        'HTTP_IIS_htr_isapi',
        'HTTP_IIS_ssi',
        'HTTP_IRunbook_FileDisclosure',
        'HTTP_Icecast_mp3',
        'HTTP_Imagemap_Exe',
        'HTTP_IndexServer_IDQ',
        'HTTP_IndexServer_SQLQHit',
        'HTTP_IndexServer_Source_Disclosure',
        'HTTP_IndexServer_Webhits',
        'HTTP_Info2WWW',
        'HTTP_InterScan_VirusWall_Overflow',
        'HTTP_InterscanViruswall_ChgCfg',
        'HTTP_InterscanViruswall_RegGo',
        'HTTP_InterscanViruswall_Smtpscan',
        'HTTP_JJ_Overflow',
        'HTTP_JRun_Double_Slash',
        'HTTP_JRun_IIS_Overflow',
        'HTTP_JRun_ISAPI_Host',
        'HTTP_JSP_SourceRead',
        'HTTP_Java',
        'HTTP_Java_Class',
        'HTTP_Java_Webadmin_BBS',
        'HTTP_Kazaa',
        'HTTP_LastlinesCgi_CmdExecute',
        'HTTP_LastlinesCgi_Traversal',
        'HTTP_Listrec_Execute',
        'HTTP_Listserv_Waexe',
        'HTTP_Lock_Method_DOS',
        'HTTP_Login_Known_User',
        'HTTP_Lotus_Domino_Dir_Traversal',
        'HTTP_MDAC_Access',
        'HTTP_MDAC_Get',
        'HTTP_MDAC_RDS_Overflow',
        'HTTP_MSCS_ProfileSvc_Overflow',
        'HTTP_MSIS_Script',
        'HTTP_MSRadio_Overflow',
        'HTTP_MachineInfo',
        'HTTP_Mailsite_Wconsole',
        'HTTP_Mambo_Phpsessid',
        'HTTP_NT8.3_Filename',
        'HTTP_Napster_Installed',
        'HTTP_Netscape_List_Directories',
        'HTTP_Netscape_Method_Overflow',
        'HTTP_Netscape_PageServices',
        'HTTP_Netscape_Revlog',
        'HTTP_Netscape_SpaceView',
        'HTTP_Netscape_URI_Overflow',
        'HTTP_Netscape_WPauth',
        'HTTP_Netscape_rend',
        'HTTP_NetwareWebserver_Traversal',
        'HTTP_Netware_DirList',
        'HTTP_Nfuse_Path',
        'HTTP_Nimda_Worm',
        'HTTP_Novell_Convert',
        'HTTP_Novell_Files',
        'HTTP_NphTestCgi',
        'HTTP_OWC_Installer_Overflow',
        'HTTP_OWC_Vulnerable_Client',
        'HTTP_Object_Type_Overflow',
        'HTTP_OfficeScan_Auth_Bypass',
        'HTTP_Officescan_Config',
        'HTTP_Omnihttp',
        'HTTP_OracleAdmin_Web_Interface',
        'HTTP_OracleAdmin_help_overflow',
        'HTTP_OracleApp_AggreSpy',
        'HTTP_OracleApp_DMSDump',
        'HTTP_OracleApp_Info',
        'HTTP_OracleApp_Spy',
        'HTTP_OracleApp_XSQL',
        'HTTP_OracleApp_demo_info',
        'HTTP_OracleApp_demo_sendmail',
        'HTTP_OracleApp_dms0',
        'HTTP_OracleApp_oprocmgr_service',
        'HTTP_OracleApp_oprocmgr_status',
        'HTTP_OracleApp_soap',
        'HTTP_Oracle_Appserver_Overflow',
        'HTTP_Oracle_Appserver_ViewInfo',
        'HTTP_Oracle_Appserver_rwcgi60',
        'HTTP_Oracle_Batchfile',
        'HTTP_OrderLog',
        'HTTP_OrderLogDat',
        'HTTP_OrderLogV12Dat',
        'HTTP_Outlook_Codebase_Execute',
        'HTTP_PDGSoft_Changepw',
        'HTTP_PHF_CommandExec',
        'HTTP_PHPMyAdmin_EvalExecute',
        'HTTP_PHPMyAdmin_SqlPhp',
        'HTTP_PHPMyAdmin_Sql_Include',
        'HTTP_PHPNuke_Admin_Access',
        'HTTP_PHPNuke_Admin_Overwrite',
        'HTTP_PHPNuke_Index_File',
        'HTTP_PHPNuke_ModulesPhp_DOS',
        'HTTP_PHPNuke_Prefix_Admin',
        'HTTP_PHPNuke_ReadFiles',
        'HTTP_PHPNuke_URL_Redirect',
        'HTTP_PHP_Includedir',
        'HTTP_PHP_LoadPrefs',
        'HTTP_PHP_Memchr_BO',
        'HTTP_PHP_Overflow',
        'HTTP_PHP_Phorum',
        'HTTP_PHP_ReadFile',
        'HTTP_POST_ComputeSum',
        'HTTP_POST_CreateTable',
        'HTTP_POST_Filename_WinIni',
        'HTTP_POST_Filename_passwd',
        'HTTP_POST_Filename_sam',
        'HTTP_POST_GroupBy',
        'HTTP_POST_PeopleSoft_IClientServlet',
        'HTTP_POST_PeopleSoft_Traversal',
        'HTTP_POST_PeopleSoft_XXE',
        'HTTP_POST_SQL_OpenRowSet',
        'HTTP_POST_SQL_UnionAllSelect',
        'HTTP_POST_SQL_UnionSelect',
        'HTTP_POST_SQL_WaitForDelay',
        'HTTP_POST_Script',
        'HTTP_POST_XP_Cmdshell',
        'HTTP_POST_dotdot_data',
        'HTTP_POST_dotdotdot_data',
        'HTTP_POST_repeated_char',
        'HTTP_Passwd_Txt',
        'HTTP_Pfdispaly_Access',
        'HTTP_Pfdispaly_Execute',
        'HTTP_Pfdispaly_Read',
        'HTTP_PhpRocket_Traversal',
        'HTTP_Pi3Web_TstIsapiDll',
        'HTTP_PlanetIntra_Overflow',
        'HTTP_Polycom_Reveal_Password',
        'HTTP_Post',
        'HTTP_PostQueryCgi',
        'HTTP_Post_Field',
        'HTTP_Post_Filename_pwl',
        'HTTP_Propfind_Very_Long',
        'HTTP_PsaPhp_RevealSource',
        'HTTP_Put',
        'HTTP_QuikStore',
        'HTTP_Realserver_Noarg',
        'HTTP_RegEcho',
        'HTTP_RingZero',
        'HTTP_Road_Search',
        'HTTP_RobotsTxt',
        'HTTP_RpcNLog',
        'HTTP_SCO_View_Source',
        'HTTP_SGI_Handler',
        'HTTP_SGI_Infosrch',
        'HTTP_SGI_Webdist',
        'HTTP_SGI_Wrap',
        'HTTP_Sambar_cgitest',
        'HTTP_ScanMail_Auth_Bypass',
        'HTTP_Script_Bypass',
        'HTTP_SendTempPl',
        'HTTP_Server_ID',
        'HTTP_SharePoint_Auth_Bypass',
        'HTTP_Shells_Bash',
        'HTTP_Shells_C',
        'HTTP_Shells_Ksh',
        'HTTP_Shells_Perl',
        'HTTP_Shells_Perl_Exe',
        'HTTP_Shells_Rksh',
        'HTTP_Shells_Sh',
        'HTTP_Shells_Tcsh',
        'HTTP_ShockWave',
        'HTTP_Shopper_Conf',
        'HTTP_SiteCsc_Access',
        'HTTP_SiteServer_Post_Dir_Traversal',
        'HTTP_SoftCart_Order_Info',
        'HTTP_SoftCart_StoreMgrPw',
        'HTTP_Sojourn',
        'HTTP_StoreCGI',
        'HTTP_SubSevenCGI',
        'HTTP_SubSeven_ICQ_Pager',
        'HTTP_Sunone_Viewlog',
        'HTTP_TektronixPrinter',
        'HTTP_Tilde',
        'HTTP_Tomcat_Nulllist',
        'HTTP_Trace',
        'HTTP_Translate_F_SourceRead',
        'HTTP_TrendVCS_Auth_Bypass',
        'HTTP_UBB_Posting_Topic',
        'HTTP_URL_BackslashDotDot',
        'HTTP_URL_Bad_Hex_Code',
        'HTTP_URL_FrontPage_Service_Password',
        'HTTP_URL_Frontpage_Ext_Backdoor',
        'HTTP_URL_IIS_Password_Change_Attempt',
        'HTTP_URL_JspPath',
        'HTTP_URL_MLog',
        'HTTP_URL_MS_ADC_Samples',
        'HTTP_URL_Many_Slashes',
        'HTTP_URL_MyLog',
        'HTTP_URL_Name_Very_Long',
        'HTTP_URL_NewDsnExe',
        'HTTP_URL_Repeated_Dot',
        'HTTP_URL_Requests_Too_Often',
        'HTTP_URL_Snork_Bat',
        'HTTP_URL_WWWBoard_Script',
        'HTTP_URL_dotpath',
        'HTTP_URL_repeated_char',
        'HTTP_URLscan',
        'HTTP_Unify_UploadServelet',
        'HTTP_Unix_Passwords',
        'HTTP_UserAgent_Too_Long',
        'HTTP_User_Agent',
        'HTTP_Verity_Search',
        'HTTP_ViaVideo_Overflow',
        'HTTP_Viewsrc_fileread',
        'HTTP_Vulnerable_Client',
        'HTTP_WWWThreads_Admin',
        'HTTP_Wayboard_Fileview',
        'HTTP_WeaknessCGIScanner',
        'HTTP_WebDAV_Long_Rqst_BO',
        'HTTP_WebDAV_Long_Rqst_DOS',
        'HTTP_WebFinger',
        'HTTP_WebLogic_FileServlet_ShowCode',
        'HTTP_WebLogic_FileSourceRead',
        'HTTP_WebLogic_PluginBO',
        'HTTP_WebLogic_fileread',
        'HTTP_WebManager_Httpsave_overflow',
        'HTTP_WebPALS',
        'HTTP_WebSite_Sample',
        'HTTP_WebSite_Uploader',
        'HTTP_WebSphere_Host',
        'HTTP_WebSphere_reveal_path',
        'HTTP_WebStore_Misconfig',
        'HTTP_WebcartCgi_Execute',
        'HTTP_Webevent',
        'HTTP_Webinf_Dot_FileRetrieval',
        'HTTP_Weblogic_SSIServlet_ShowCode',
        'HTTP_Webmin_Traversal',
        'HTTP_WebpageCgi_ViewInfo',
        'HTTP_Webplus',
        'HTTP_Websendmail',
        'HTTP_Webspeed_Admin',
        'HTTP_WhiskerScan',
        'HTTP_Whois',
        'HTTP_WikkiTikkiTavi_Remote_Template',
        'HTTP_WinMX',
        'HTTP_Win_Repair',
        'HTTP_WindMail_FileRead',
        'HTTP_Windows_Executable',
        'HTTP_XStat',
        'HTTP_Y3K_ICQ_Pager',
        'HTTP_YaBB',
        'HTTP_Yahoo_Email_Attachment',
        'HTTP_Zero_Hex_Code',
        'HTTP_ZmlCgi',
        'HTTP_cookieOverflow',
        'HTTP_formmailpl',
        'HTTP_iHTML_Merchant_File_Access',
        'HTTP_iPlanet_Search_BO',
        'HTTP_iPlanet_Search_ViewFiles',
        'HTTP_lotsOfURLs',
        'HTTP_mailnews_post',
        'HTTP_phpBB2',
        'HTTP_repeated_character',
        'HTTP_rguestexe',
        'HTTP_testcgi',
        'HTTP_testcgitcl',
        'HTTP_webgais',
        'HTTP_wguestexe',
        'HVL_RAT_Response',
        'HackATack_Ping',
        'HackATack_TCP_Response',
        'HackATack_UDP_Response',
        'HackersParadise_Response',
        'HostControl_Response',
        'ICMP',
        'Incoming',
        'ICMP_Flood',
        'ICMP_Modem_DoS',
        'ICMP_Redirect',
        'ICMP_Source_Quench',
        'ICMP_Subnet_Mask_Request',
        'ICMP_Timestamp_Request',
        'ICMP_Unreachable_Storm',
        'IDENT_Generic_Intel_Overflow',
        'IIS_FTP_Session_Status_DoS',
        'IIS_Reveal_Address',
        'IMAP4_Very_Long_Command',
        'IMAP_Auth_Failed',
        'IMAP_Generic_Intel_Overflow',
        'IMAP_Imail_Overflow',
        'IMAP_Login',
        'IMAP_Long_Authname',
        'IMAP_Long_Login',
        'IMAP_Long_Mbox',
        'IMAP_Long_Parm',
        'IMAP_Long_Password',
        'IMAP_Password',
        'IMAP_Too_Many_Connects',
        'IMAP_WU_Imapd_BO',
        'IP',
        'Incoming',
        'IPDuplicate',
        'IP_Duplicate',
        'IP_Flushot',
        'IP_Fragment_Empty',
        'IP_Hdr_Options_Zero_Length',
        'IP_Microfragment',
        'IP_OShare',
        'IP_PingOfDeath_Jolt2',
        'IP_Ping_Of_Death_Jolt',
        'IP_SS_Ping',
        'IP_SourceRoute',
        'IP_Timestamp_Not_Aligned',
        'IP_Unknown_Protocol',
        'IPv6_Native',
        'IRC_Automated_Client',
        'IRC_DCC_Chat',
        'IRC_DCC_Request',
        'IRC_DCC_Send',
        'IRC_Daemon_Overflow',
        'IRC_Generic_Intel_Overflow',
        'IRC_Global_Threat',
        'IRC_Join',
        'IRC_Join_Attempt',
        'IRC_Litmus',
        'IRC_Msg',
        'IRC_Nick',
        'IRC_Notice',
        'IRC_PrettyPark_Worm',
        'IRC_SubSeven_Notification',
        'IRC_TrinityV3_Notification',
        'IRC_Trinity_Notification',
        'IRC_Vscan',
        'IRC_Y3K_Notification',
        'IRDP_Gateway_Spoof',
        'ISA_Abnormal_Termination',
        'ISA_Alert_Failed_Log',
        'ISA_FW_Init_Failed',
        'ISA_FW_Start_Failed_Corrupt',
        'ISA_FW_Stop',
        'ISA_Failed_To_Start',
        'ISA_LOG_File_Write_Failed',
        'ISA_LOG_Service_Stopped_Logging_Failure',
        'ISA_PF_Create_PF_Failure',
        'ISA_PF_Dial_Out_Rebind_Failure',
        'ISA_PF_Dropping_Packets',
        'ISA_PF_Filtering_Disabled',
        'ISA_PF_IP_PF_Create_Failure',
        'ISA_PF_Insecure_Config',
        'ISA_PF_Interface_Bind_Failure',
        'ISA_PF_No_Ext_Interface',
        'ISA_PF_Protocol_Violation',
        'ISA_SCS_Init_Failed',
        'ISA_SCS_Stop',
        'ISA_Server_Init_Failed_Corrupt',
        'ISA_Server_NAT_Insecure',
        'ISA_WPS_Stop',
        'ISA_WPS_Terminated',
        'ISS_Ident',
        'ISS_Scan_7_0_ICMP',
        'ISS_Scan_FTP',
        'ISS_Scan_ICMP',
        'ISS_Scan_UDP',
        'ISS_SunRPC',
        'ISS_Wireless_Scanner_DHCP',
        'IS_High_Vulnerability_Found',
        'IS_Low_Vulnerability_Found',
        'IS_Medium_Vulnerability_Found',
        'IS_Scan_Completed',
        'IS_Scan_Started',
        'Ident_Error',
        'Ident_Flood',
        'Ident_Invalid_Response',
        'Ident_Newline',
        'Ident_Overflow',
        'Ident_Scan',
        'Ident_Suspicious_ID',
        'Ident_User',
        'Ident_Version',
        'Infector_FTP_Response',
        'Infector_Response',
        'InfraTrojan_Request',
        'Insane_Network_Backdoor',
        'Interscan_Viruswall_Httpsave',
        'Intruzzo_TCP_Response',
        'Kerberos_User_Snarf',
        'KidTerror_Response',
        'Kuang2Virus_Response',
        'LDAP_IMail_Overflow',
        'LDAP_blacklist_failed',
        'LDAP_blacklist_permanent',
        'LDAP_blacklist_short-term',
        'LPRng_Format_String',
        'LanMan_Share_Enum',
        'LanMan_Share_Enum_Sweep',
        'Land_Attack',
        'LeakTest_Request',
        'Local_group_changed',
        'Local_group_created',
        'Local_group_deleted',
        'Local_group_user_added',
        'Local_group_user_removed',
        'Log_on_to_account_failed',
        'Logon_process_registered',
        'Logon_with_admin_privileges',
        'Logon_with_special_privileges',
        'Loki',
        'MSMessenger_Login',
        'MSMessenger_Message',
        'MSRPC_Domaindump',
        'MSRPC_Dump',
        'MSRPC_LSA_Crash',
        'MSRPC_LSA_DoS',
        'MSRPC_Locator_BO',
        'MSRPC_Lookupnames',
        'MSRPC_Malformed_DOS',
        'MSRPC_Message_Que_Heap_BO',
        'MSRPC_Popup_Message',
        'MSRPC_RFPoison_Attack',
        'MSRPC_Registry_Key',
        'MSRPC_Registry_PolicySecrets',
        'MSRPC_Registry_Read_MS_Index_Server',
        'MSRPC_Registry_Read_Sql_Execpass',
        'MSRPC_Registry_Request_DoS',
        'MSRPC_Registry_SAM',
        'MSRPC_Registry_Write',
        'MSRPC_Registry_Write_IMail_Admin',
        'MSRPC_Registry_Write_RASMan',
        'MSRPC_Registry_Write_RDS',
        'MSRPC_Registry_Write_Run',
        'MSRPC_Registry_Write_aedebug',
        'MSRPC_RemoteActivate_Bo',
        'MSRPC_RemoteActivate_Path_BO',
        'MSRPC_Security_Id_Lookup',
        'MSRPC_Share_Dump',
        'MSRPC_Share_Enum',
        'MSRPC_Share_Enum_Sweep',
        'MSRPC_User_Enum',
        'MSRPC_WksSvc_Mgmnt_Bo',
        'MSSQL_Failed_Connection',
        'MSSQL_Shutdown',
        'MSSQL_Startup',
        'MSSQL_Successful_Non-Trusted_Connection',
        'MSSQL_Successful_Trusted_Connection',
        'Malformed_Packet_Storm',
        'Mapped_account',
        'Mapped_account_failed',
        'MastersParadise98_Response',
        'MavericksMatrix_Response',
        'Michal_TCP_Response',
        'Microsoft_Windows_Shell_Banner',
        'Millenium_Response',
        'MountdExport',
        'Mstream_Master',
        'Mstream_Zombie_Request',
        'Mstream_Zombie_Response',
        'NCX_Backdoor_Response',
        'NNTP_Cancel_Overflow',
        'NNTP_Control',
        'NNTP_From_Overflow',
        'NNTP_Group',
        'NNTP_MesgID_Overflow',
        'NNTP_Password',
        'NNTP_Pipe',
        'NNTP_Subject',
        'NNTP_User',
        'NNTP_Xchg_Auth',
        'NTP_Readvar_Overflow',
        'NTP_SNTP_Malformed',
        'NTP_Time',
        'Nachi_Ping_Sweep',
        'Napster_Client_Update',
        'Napster_Create_Account',
        'Napster_Download',
        'Napster_Login',
        'Napster_Login_Info',
        'Napster_Private_Msg',
        'Napster_Public_Msg',
        'Napster_Search',
        'Napster_Sharing',
        'Nessus_Scanner',
        'Nestea',
        'NetBus_Pro_Request',
        'NetBus_Response',
        'NetMeeting_Directory_Traversal',
        'NetSphere_Client',
        'NetSphere_FTP_Response',
        'NetSphere_Response',
        'NetSpyV12_Response',
        'NetSpy_Response',
        'Netbios_Name_Scan',
        'Netbios_Session_Granted',
        'Netbios_Session_Rejected',
        'Netbios_Session_Request',
        'Network_Normal',
        'Network_Quiet',
        'NewTear',
        'Nmap_OS_Fingerprint',
        'Nmap_Ping',
        'OSPF_Database_Desc',
        'OSPF_Database_Desc_Multicast',
        'OSPF_Hello',
        'OSPF_Hello_Multicast',
        'OSPF_Invalid_Packet_Length',
        'OSPF_Link_State_Ack',
        'OSPF_Link_State_Ack_Multicast',
        'OSPF_Link_State_Update',
        'OSPF_Link_State_Update_Multicast',
        'OSPF_Lnk_State_Req',
        'OSPF_Lnk_State_Req_Multicast',
        'OSPF_Null_Authentication',
        'OSPF_Short_Header',
        'OSPF_Unknown_Msg_Type',
        'Oracle_Connect_Internal',
        'Oracle_Failed_Connection',
        'Oracle_Failed_Object_Access',
        'Oracle_Listener_Debug_DoS',
        'Oracle_Shutdown',
        'Oracle_Startup',
        'Oracle_Successful_Connection',
        'Oracle_Successful_Object_Access',
        'Out_of_virtual_memory',
        'Overnet_Search',
        'PAM_Internal_Error',
        'POP3_Auth_Failed',
        'POP_APOP_Name_Overflow',
        'POP_Command_Overflow',
        'POP_Filename',
        'POP_Filename_Chars',
        'POP_Filename_Overflow',
        'POP_Filename_Space_Overflow',
        'POP_Fold_Overflow',
        'POP_Fuseware_Overflow',
        'POP_Generic_Intel_Overflow',
        'POP_List_Overflow',
        'POP_Login_Overflow',
        'POP_Password',
        'POP_Password_Overflow',
        'POP_QPopAuth_Overflow',
        'POP_QPopUser_Overflow',
        'POP_Retr_DoS',
        'POP_Server_Identity',
        'POP_SilentRunner_Pass_Overflow',
        'POP_SilentRunner_User_Overflow',
        'POP_Too_Many_Connects',
        'POP_User',
        'POP_User_Root',
        'PPTP_Badmagic',
        'Packet_Capturing_Remote',
        'Packet_Capturing_Tool',
        'Password_change_failed',
        'Password_change_successful',
        'PcnfsdExec',
        'PhaseZero_Response',
        'PingOfDeath',
        'Ping_Flood',
        'Ping_Sweep',
        'PmapMnt',
        'PmapProxy',
        'PortalOfDoom_Response',
        'Portmaster_Reboot',
        'Preauthentication_failed',
        'Privileged_service_called',
        'Probing_of_important_files',
        'Progenic_Response',
        'Program_execution_started',
        'Program_exited',
        'Prosiak_Response',
        'QAZ_Backdoor_Email',
        'QAZ_Backdoor_Request',
        'QAZ_Backdoor_Response',
        'Qpopper_Auth_failed',
        'Qpopper_Permission_Problem',
        'Qpopper_Possible_user_probe',
        'Qpopper_Username_too_long',
        'Quake3Arena_Vulnerable_Client',
        'Quake3Arena_Vulnerable_Server',
        'Quake_Backdoor_Request',
        'Queso_Scan',
        'RDP_Login',
        'RIP_Add',
        'RIP_Expire',
        'RIP_Metric_Change',
        'RPC_Admind_Auth',
        'RPC_Amd_Overflow',
        'RPC_Amd_Pid',
        'RPC_Amd_Version',
        'RPC_AutoFS_Shell',
        'RPC_Automountd_Overflow',
        'RPC_CALLIT_Request',
        'RPC_Cachefsd_Overflow',
        'RPC_CallIt_Unknown',
        'RPC_Cmsd_Overflow',
        'RPC_Corrupt_Credentials',
        'RPC_GETPORT_Request',
        'RPC_Generic_Intel_Overflow',
        'RPC_GetPort',
        'RPC_KCMS_File_Retrieval',
        'RPC_Large_Fragmented',
        'RPC_Mount_Overflow',
        'RPC_Mountd_Mnt',
        'RPC_NFS_FHSize_Overflow',
        'RPC_NFS_Guess',
        'RPC_NFS_Mknod',
        'RPC_NFS_Over_LOCKD',
        'RPC_NFS_UID_Zero',
        'RPC_NIS_Overflow',
        'RPC_PCNFSD_Backdoor',
        'RPC_PcnfsdShell',
        'RPC_Pcnfsd_Overflow',
        'RPC_Portmap_Dump',
        'RPC_Portmap_Getport',
        'RPC_Portmap_High_Port',
        'RPC_Portmap_Set',
        'RPC_Portmap_Set_Spoof',
        'RPC_Portmap_Unset',
        'RPC_Portmap_Unset_Spoof',
        'RPC_Probe',
        'RPC_SGI_Fam_Access',
        'RPC_Sadmind_Ping',
        'RPC_Statd_Automount_Exec',
        'RPC_Statd_DotDot',
        'RPC_Statd_Format_Attack',
        'RPC_Statd_Overflow',
        'RPC_Suspicious_Host_Credentials',
        'RPC_Tooltalkd_Overflow',
        'RPC_Xfsmd_Execute',
        'RPC_YPPasswd_Overflow',
        'RPC_Ypbind_DirClimb',
        'RPC_Ypupdate_Exec',
        'RPC_snmpXdmid_Overflow',
        'Radius_Generic_Intel_Overflow',
        'Radius_Password_Buffer_Overflow',
        'Radius_User_Buffer_Overflow',
        'RealSecure_Kill',
        'RedHat_LPD_Print_Control',
        'Registry_NT_security_options_changed',
        'Registry_autorun_changed',
        'Registry_eventlog_settings_changed',
        'Registry_remote_edit_changed',
        'RemoteStorm_Response',
        'RemoteWatch_Response',
        'RemoteWindowsShutdown_Response',
        'Retina_Scanner',
        'Rexd',
        'Rexec',
        'Rlogin_Auth_Failed',
        'Rlogin_Excessive_Tabs',
        'Rlogin_Froot',
        'Rlogin_Known_User',
        'Rlogin_Login',
        'Rlogin_Name_Very_Long',
        'Rlogin_Password_Overflow',
        'Rlogin_TERM_Very_Long',
        'Rlogin_Trusted_Login',
        'Rsh_Session',
        'RuxTick_Request',
        'Rwhod_Overflow',
        'S2_Scan_Completed',
        'S2_Scan_Started',
        'S2_Scan_Vulnerability_Found',
        'SIIT_Tunnel',
        'SMB_Admin_Sneak',
        'SMB_Auth_Failed',
        'SMB_Autoexec_bat_Access',
        'SMB_Client_Cleartext_Password',
        'SMB_Empty_Password',
        'SMB_Filename',
        'SMB_Filename_Overflow',
        'SMB_Guessable_Password',
        'SMB_IO_Printer_Share',
        'SMB_LSA_Connect',
        'SMB_Malformed',
        'SMB_Nimda_Worm',
        'SMB_Password_File',
        'SMB_Password_Overflow',
        'SMB_Pwl_Filetype',
        'SMB_RFParalyze',
        'SMB_Sam_File',
        'SMB_Samba_Transaction2_bo',
        'SMB_Service_Sweep',
        'SMB_Startup_File_Access',
        'SMB_Transact_Bo',
        'SMB_Unicode_Filename_Overflow',
        'SMB_Win_ini_file',
        'SMB_Winreg_File',
        'SMTP_Etrn_Overflow',
        'SMTP_Exchange_Verb_DoS',
        'SMTP_Expn_Metachar',
        'SMTP_Loopback_Bounce',
        'SMTP_Malformed_Rcpt_Cmd',
        'SMTP_ParseAddr_Overflow',
        'SMTP_Probe_Root',
        'SMTP_Relay_Not_Allowed',
        'SMTP_Sendmail_Header_Parse_Overflow',
        'SMTP_Too_Many_Connects',
        'SMTP_User_Unknown',
        'SMTP_Virus_Recipient',
        'SNMP_3COM_Communities',
        'SNMP_Activity',
        'SNMP_AuthTraps_Disable',
        'SNMP_Bad_ErrorIndex',
        'SNMP_Bad_ErrorStatus',
        'SNMP_Bad_Generic_Trap',
        'SNMP_Bad_RequestId',
        'SNMP_Bad_Specific_Trap',
        'SNMP_Bad_Trap_AgentAddr',
        'SNMP_Bad_Variable_Type',
        'SNMP_CiscoMgmt_Ping',
        'SNMP_Cisco_Passwd',
        'SNMP_Cisco_VACM_MIB',
        'SNMP_Cisco_Zero_Size_DOS',
        'SNMP_Community',
        'SNMP_Community_Format_String',
        'SNMP_Community_Long',
        'SNMP_Community_Underflow',
        'SNMP_Corrupt_Traffic',
        'SNMP_Counter64',
        'SNMP_Crack',
        'SNMP_Default_Backdoor',
        'SNMP_Delete_WINS',
        'SNMP_Dialup_Hangup',
        'SNMP_Dialup_Phone_Number',
        'SNMP_Dialup_Username',
        'SNMP_Discovery_Broadcast',
        'SNMP_Echo_Bounce',
        'SNMP_FormatString',
        'SNMP_HP_ProCurve',
        'SNMP_HP_Route_Metachar',
        'SNMP_Indefinite_Length',
        'SNMP_Int_Overflow',
        'SNMP_Int_Underflow',
        'SNMP_InvalidTag_Community',
        'SNMP_InvalidTag_Enterprise',
        'SNMP_InvalidTag_ErrorIndex',
        'SNMP_InvalidTag_ErrorStatus',
        'SNMP_InvalidTag_GenericTrap',
        'SNMP_InvalidTag_OID',
        'SNMP_InvalidTag_PDU',
        'SNMP_InvalidTag_Packet',
        'SNMP_InvalidTag_RequestID',
        'SNMP_InvalidTag_SpecificTrap',
        'SNMP_InvalidTag_Trap_Timestamp',
        'SNMP_InvalidTag_VarBind',
        'SNMP_InvalidTag_VarBindList',
        'SNMP_InvalidTag_Version',
        'SNMP_Lanman_Enum',
        'SNMP_Length_Underflow',
        'SNMP_Long_Field_Length',
        'SNMP_Long_OID',
        'SNMP_NonZeroLength_NullType',
        'SNMP_NullInCommunity',
        'SNMP_NullInString',
        'SNMP_OID_Overflow',
        'SNMP_OID_Underflow',
        'SNMP_PDU_Underflow',
        'SNMP_Packet_Underflow',
        'SNMP_RMON_Collections',
        'SNMP_Set',
        'SNMP_Show_LMUsers',
        'SNMP_Sun_Backdoor',
        'SNMP_Suspicious_Get',
        'SNMP_Suspicious_Set',
        'SNMP_Suspicious_Version_Size',
        'SNMP_SysContact',
        'SNMP_Sysname_Overflow',
        'SNMP_TFTP_Retrieval',
        'SNMP_TooManyVariables',
        'SNMP_Trap_Address_Underflow',
        'SNMP_Trap_Enterprise_Invalid',
        'SNMP_Trap_Enterprise_Underflow',
        'SNMP_Trap_Timestamp_Underflow',
        'SNMP_UInt_Overflow',
        'SNMP_UInt_Underflow',
        'SNMP_Value_Underflow',
        'SNMP_VarBindList_Underflow',
        'SNMP_VarBind_Underflow',
        'SNMP_Version_Underflow',
        'SNMP_ifTable',
        'SNMP_ipForwarding',
        'SNMP_ipRouteTable',
        'SNMP_trapAuthFailure',
        'SOCKS4_Connect',
        'SOCKS5_Connect',
        'SOCKS5_Username_BO',
        'SOCKS_Bounce',
        'SOCKS_Over_SOCKS',
        'SQLServer_login_failed',
        'SQLServer_login_failed_not_administrator',
        'SQLServer_login_failed_not_trusted',
        'SQLServer_login_failed_not_valid_user',
        'SQLServer_login_failed_too_many_users',
        'SQL_Auth_Failed',
        'SQL_Jet_ODS_Overflow',
        'SQL_LogExplorer_Overflow',
        'SQL_Login',
        'SQL_OpenRowSet_Overflow',
        'SQL_PreAuth_Overflow',
        'SQL_PwdEncrypt_Overflow',
        'SQL_SSRP_DoS',
        'SQL_SSRP_HeapBo',
        'SQL_SSRP_Slammer_Worm',
        'SQL_SSRP_StackBo',
        'SQL_Spida_Worm',
        'SQL_XP_WeakPermissions',
        'SSH2_Agent_forwarding_denied',
        'SSH2_Common_auth_failed_host',
        'SSH2_Common_auth_failed_user',
        'SSH2_DNS_lookup_failed',
        'SSH2_Hostbased_auth_failed_DNS_spoofing',
        'SSH2_Hostbased_auth_failed_for_user',
        'SSH2_Hostbased_auth_failed_no_root',
        'SSH2_Hostbased_auth_failed_packet_error',
        'SSH2_Hostbased_auth_failed_pubkey',
        'SSH2_Hostbased_auth_successful',
        'SSH2_Illegal_port_forwarding',
        'SSH2_Kerberos_auth_failed',
        'SSH2_Kerberos_auth_successful',
        'SSH2_Login_General',
        'SSH2_Pam_auth_failed',
        'SSH2_Passwd_auth_failed_empty_passwd',
        'SSH2_Passwd_auth_failed_root',
        'SSH2_Passwd_auth_failed_wrong_passwd',
        'SSH2_Passwd_auth_successful',
        'SSH2_Pubkey_auth_failed',
        'SSH2_Pubkey_auth_failed_root',
        'SSH2_Pubkey_auth_successful',
        'SSH2_Rhosts_auth_failed',
        'SSH2_SSH1_Agent_forwarding_denied',
        'SSH2_TCPIP_forwarding_denied',
        'SSH2_Username_too_long',
        'SSH_Banner_Length',
        'SSH_ChallengeReponse_Bo',
        'SSH_Deattack_IO',
        'SSH_Version',
        'SSL2_Master_Key_Overflow',
        'SSL_PCT1_Overflow',
        'SYNFlood',
        'Sadmind_Amslverify_Overflow',
        'Saihyousen_Attack',
        'Satan_FTP',
        'Satan_UDP',
        'SatansBackdoor_Response',
        'Schwindler_Response',
        'SecretService_Response',
        'Security_disabled_global_group_changed',
        'Security_disabled_global_group_created',
        'Security_disabled_global_group_deleted',
        'Security_disabled_global_group_member_added',
        'Security_disabled_global_group_member_removed',
        'Security_disabled_local_group_changed',
        'Security_disabled_local_group_created',
        'Security_disabled_local_group_deleted',
        'Security_disabled_local_group_member_added',
        'Security_disabled_local_group_member_removed',
        'Security_disabled_universal_group_changed',
        'Security_disabled_universal_group_created',
        'Security_disabled_universal_group_deleted',
        'Security_disabled_universal_group_member_added',
        'Security_disabled_universal_group_member_removed',
        'Security_enabled_universal_group_changed',
        'Security_enabled_universal_group_created',
        'Security_enabled_universal_group_deleted',
        'Security_enabled_universal_group_member_added',
        'Security_enabled_universal_group_member_removed',
        'SelSvcH',
        'SensorStatistics',
        'SensorStatistics_Cumulative',
        'ServeMe_Response',
        'Service_ticket_granted',
        'Service_ticket_request_failed',
        'Session_disconnected',
        'Session_reconnected',
        'Slapper_Worm',
        'Smurf_Attack',
        'SnidX2_Response',
        'SniperNet_Response',
        'Snoop_GetQuota_Overflow',
        'Snork_Attack',
        'Snort_Stream4_HeapBo',
        'SocketsDeTroie_Request',
        'Socks_Auth_Failed',
        'Solaris_LPD_Overflow',
        'Stacheldraht_Agent',
        'Stacheldraht_Handler',
        'Startup_of_important_programs',
        'StealthSpy_Response',
        'Stream_DoS',
        'Stumbler_ChangeAddress',
        'Stumbler_Connect',
        'Stumbler_Probe',
        'SubSeven_Pass_Response',
        'SubSeven_Response',
        'SubSeven_Scan_Response',
        'Successful_Network_login',
        'Successful_login',
        'Sun_SNMP_Backdoor',
        'Suspect_FTP',
        'Suspect_Finger',
        'Suspect_IMAP',
        'Suspect_Netbus',
        'Suspect_Netstat',
        'Suspect_POP2',
        'Suspect_POP3',
        'Suspect_SMTP',
        'Suspect_SSH',
        'Suspect_Sunrpc',
        'Suspect_Systat',
        'Suspect_Telnet',
        'Suspect_Time',
        'Suspect_WWW',
        'Suspect_Whois',
        'Suspect_portscan',
        'Swift_Request',
        'Sybase_Failed_Connection',
        'Sybase_No_Configuration_File',
        'Sybase_Shutdown',
        'Sybase_Startup',
        'Sybase_Successful_Connection',
        'SynDrop',
        'Synthesized_Host_Attack_Flood',
        'Synthesized_Network_Attack_Flood',
        'Syphillis_Response',
        'Syphillis_Scan_Request',
        'Syphillis_Scan_Response',
        'Syslog_Cisco_Zero_Size_DoS',
        'TCP',
        'Incoming',
        'TCP_ACK_Ping',
        'TCP_Data_Changed',
        'TCP_FIN_Scan',
        'TCP_Fin_OutOfRange',
        'TCP_Flag_SynUrg',
        'TCP_Frag_RFProwl',
        'TCP_Fragmented_Header',
        'TCP_Hijacking_Tool',
        'TCP_Multiple_Syns',
        'TCP_Null_Scan',
        'TCP_OS_Fingerprint',
        'TCP_Port_Scan',
        'TCP_Probe_BitTorrent',
        'TCP_Probe_DNS',
        'TCP_Probe_Finger',
        'TCP_Probe_Ftp',
        'TCP_Probe_Gnutella',
        'TCP_Probe_HTTP',
        'TCP_Probe_IRC',
        'TCP_Probe_Ident',
        'TCP_Probe_Imap4',
        'TCP_Probe_LinuxConf',
        'TCP_Probe_Lpr',
        'TCP_Probe_MSRPC',
        'TCP_Probe_NNTP',
        'TCP_Probe_NetBIOS',
        'TCP_Probe_Netbus',
        'TCP_Probe_Other',
        'TCP_Probe_POP3',
        'TCP_Probe_PPTP',
        'TCP_Probe_Proxy',
        'TCP_Probe_Rlogin',
        'TCP_Probe_SMTP',
        'TCP_Probe_SQL',
        'TCP_Probe_Socks',
        'TCP_Probe_Sub7',
        'TCP_Probe_SunRPC',
        'TCP_Probe_T0rn',
        'TCP_Probe_Telnet',
        'TCP_Probe_Trojan',
        'TCP_Probe_XWindows',
        'TCP_Seq_OutOfRange',
        'TCP_Service_Sweep',
        'TCP_Short_Header',
        'TCP_Small_Segment_Size',
        'TCP_Urg_OutOfRange',
        'TCP_Xmas_Scan',
        'TCP_Zero_Length_Option',
        'TFN2K_ICMP_Command',
        'TFN2K_TCP_Command',
        'TFN2K_UDP_Command',
        'TFN_Daemon',
        'TFTP_Alcatel_Update',
        'TFTP_Echo_Bounce',
        'TFTP_Exe_Transfer',
        'TFTP_File_Not_Found',
        'TFTP_Filename_Overflow',
        'TFTP_Filename_VeryLong',
        'TFTP_Get',
        'TFTP_Hosts_File',
        'TFTP_Image_Transfer',
        'TFTP_MSBlaster_Attempt',
        'TFTP_MSBlaster_Worm',
        'TFTP_Nachi_Worm',
        'TFTP_Nimda_Query',
        'TFTP_Nimda_Response',
        'TFTP_PWL_File',
        'TFTP_Passwd_File',
        'TFTP_Put',
        'TFTP_Sam_File',
        'TFTP_Traversal',
        'TFTP_WinIni_File',
        'Talk_Flash',
        'Talk_Request',
        'TearDrop',
        'TearDrop2',
        'TeleCommando_Response',
        'Telnet_Abuse',
        'Telnet_Auth_Failed',
        'Telnet_Auth_Kerb4',
        'Telnet_Auth_Kerb5',
        'Telnet_Auth_Loki',
        'Telnet_Auth_Null',
        'Telnet_Auth_Rsa',
        'Telnet_Auth_Spx',
        'Telnet_Auth_User',
        'Telnet_Auth_User_Overflow',
        'Telnet_Bad_IFS',
        'Telnet_Bad_Term',
        'Telnet_Bad_Xdisplay',
        'Telnet_Env_All',
        'Telnet_Env_Overflow',
        'Telnet_Env_Termcap',
        'Telnet_Environ_FTA',
        'Telnet_Excessive_Tabs',
        'Telnet_Inline_Demo_Capslock',
        'Telnet_Known_User',
        'Telnet_Linker_Bug',
        'Telnet_Login',
        'Telnet_Login_Overflow',
        'Telnet_NTLM_Tickle',
        'Telnet_Password_Overflow',
        'Telnet_PolycomDoS',
        'Telnet_Polycom_Blank_Password',
        'Telnet_Resolve_Host_Conf',
        'Telnet_Solaris_Forced_Login',
        'Telnet_Term_Type_Overflow',
        'Telnet_Terminal_Type',
        'Telnet_Too_Many_AYTs',
        'Telnet_Xdisplay',
        'Telnet_Xdisplay_Overflow',
        'TheThing_Response',
        'Ticket_granted_renewed',
        'Tini_Response',
        'Tivoli_LCF_Default_Password',
        'Tivoli_LCF_File_Read',
        'TotalEclypse_Response',
        'Trace_Route',
        'Trace_Route_UDP',
        'TransScout_Request',
        'Trin00_Daemon_Request',
        'Trin00_Daemon_Response',
        'Trinoo_Master_Request',
        'Trinoo_Master_Response',
        'Trusted_domain_added',
        'Trusted_domain_removed',
        'Truva_Response',
        'Twinge_Attack',
        'UDP',
        'Incoming',
        'UDP_Bomb',
        'UDP_Port_Loopback',
        'UDP_Port_Scan',
        'UDP_Probe_CharGen',
        'UDP_Probe_DNS',
        'UDP_Probe_Echo',
        'UDP_Probe_MSDNS',
        'UDP_Probe_MSRPC',
        'UDP_Probe_NFS',
        'UDP_Probe_NFS_Lockd',
        'UDP_Probe_Norton_AV',
        'UDP_Probe_Other',
        'UDP_Probe_Qotd',
        'UDP_Probe_SNMP',
        'UDP_Probe_TFTP',
        'UDP_Probe_Trojan',
        'UDP_Quake3_Exploit',
        'UDP_Service_Sweep',
        'UDP_Short_Header',
        'UDnetwork_template',
        'UNIX_Root_Login_Successful',
        'UNIX_Root_Su_Failure',
        'UNIX_Root_Su_Successful',
        'Ultors_Response',
        'Unexplained_Backdoor_Response',
        'Use_of_user_rights',
        'User',
        'Defined',
        'Audit',
        'Policy',
        'User_account_changed',
        'User_account_created',
        'User_account_deleted',
        'User_account_disabled',
        'User_account_enabled',
        'User_account_locked_out',
        'User_account_used_for_logon',
        'User_added_to_global_admin_group',
        'User_added_to_local_admin_group',
        'User_admin_right_granted',
        'User_admin_right_revoked',
        'User_logout',
        'User_right_granted',
        'User_right_revoked',
        'VNC_Detected',
        'VNC_HTTP_Get_Overflow',
        'VNC_Login_Failed',
        'VNC_Login_Failed_User',
        'VNC_NoAuthentication',
        'VNC_RFBConnFailed_Overflow',
        'VagrNoker_Response',
        'Vampire_TCP_Response',
        'WhatsUpPing',
        'Win2K_DomainController_DOS',
        'WinNuke_Attack',
        'WinTrin00_Daemon_Request',
        'WinTrin00_Daemon_Response',
        'Win_IGMP_DOS',
        'Win_IP_Src_Route',
        'Win_MessengerPopup_Bo',
        'Windows_Access_Error',
        'Windows_Null_Session',
        'Windows_Printing_Service_DOS',
        'XDMCP_Overflow',
        'XFS_Invalid_Opcode',
        'Y3K_Ping',
        'Y3K_TCP_Response',
        'Y3K_UDP_Response',
        'YahooMSG_AddView',
        'YahooMSG_File_Transfer',
        'YahooMSG_Login',
        'YahooMSG_Message',
        'YahooMSG_Message_Chat',
        'YahooMSG_PeertoPeer',
        'YahooMSG_URL_Handler_Overflow',
        'YahooMSG_UserID_Overflow',
        'dcomdef_deny',
        'dcomsrv_deny',
        'dns_bad_pkts',
        'dns_cname',
        'dns_inv_dom',
        'dns_inv_dom_offset',
        'dns_inv_dom_pkt',
        'dns_inv_updated',
        'dns_maxlen_pkt',
        'dns_name_offset',
        'dns_unauth_xfer',
        'drw_stack_ovflw',
        'evt_logcorrupt',
        'evt_logfull',
        'evt_openfail',
        'netmon_start',
        'pcAnywhere_Login',
        'pcAnywhere_Login_Failed',
        'pcAnywhere_Ping',
        'pcAnywhere_Probe',
        'ras_auth_rasfail',
        'ras_auth_timeout',
        'ras_noaccess',
        'scm_logon_fail',
        'sec_auditlost',
        'sscan_Scan',    ]

    def process(self):

        if self.plugin["source"] == 'snmp':
            self.__processSyslog()
            
        else:
            util.debug (__name__,  "log type " + self.plugin["source"] +\
                        " unknown for RealSecure...", '!!', 'RED')
            sys.exit()


    def __processSyslog(self):
        
        util.debug ('ParserRealSecure', 'plugin started (syslog)...', '--')

        pattern = 'ISS-MIB::eventEntryName\d*\.\"\"\s+=\s+STRING:\s+' +\
            '(\S+)\s+' +\
            'ISS-MIB::eventEntryTime\d*\.\"\"\s+=\s+STRING:\s+' +\
            '(\d+-\d+-\d+\s+\d+:\d+:\d+)\s+' +\
            'ISS-MIB::eventEntryProtocol\d*\.\"\"\s+=\s+STRING:\s+' +\
            '(\S+)\s+\(\d+\)\s+' +\
            'ISS-MIB::eventEntrySourceIpAddress\d*\.\"\"\s+=\s+STRING:\s+' +\
            '(\S+)\s+' +\
            'ISS-MIB::eventEntryDestinationIpAddress\d*\.\"\"\s+=\s+STRING:\s+' +\
            '(\S+)\s+' +\
            'ISS-MIB::eventEntryIcmpType\d*\.\"\"\s+=\s+STRING:\s+' +\
            '(\S+)\s+' +\
            'ISS-MIB::eventEntryIcmpCode\d*\.\"\"\s+=\s+STRING:\s+' +\
            '(\S+)\s+' +\
            'ISS-MIB::eventEntrySourcePort\d*\.\"\"\s+=\s+STRING:\s+' +\
            '(\S+)\s+' +\
            'ISS-MIB::eventEntryDestinationPort\d*\.\"\"\s+=\s+STRING:\s+' +\
            '(\S+)\s+'

        location = self.plugin["location"]
        try:
            fd = open(location, 'r')
        except IOError, e:
            util.debug(__name__, e, '!!', 'RED')
            sys.exit()
        priority = 1
            
        # Move to the end of file
        fd.seek(0, 2)
           
        while 1:
            
            if self.plugin["enable"] == 'no':

                # plugin disabled, wait for enabled
                util.debug (__name__, 'plugin disabled', '**', 'RED')
                while self.plugin["enable"] == 'no':
                    time.sleep(1)
                    
                # lets parse again
                util.debug (__name__, 'plugin enabled', '**', 'GREEN')
                fd.seek(0, 2)

            where = fd.tell()
            line = fd.readline()
            if not line: # EOF reached
                time.sleep(1)
                fd.seek(where)
            else:

                # first one line with the priority
                if   line.__contains__('lowpriorityevent'):
                    priority = 1
                elif line.__contains__('mediumpriorityevent'):
                    priority = 2
                elif line.__contains__('highpriorityevent'):
                    priority = 3
                    
                # afterwards the real secure alert
                else:

                    result = re.findall(str(pattern), line)
                    try: 
                        (name, date, protocol, src_ip, dst_ip, icmp_type,
                        icmp_code, src_port, dst_port) = result[0]
                        sid = ParserRealSecure.eventEntryNames.index(name) + 1

                        self.agent.sendAlert  (type = 'detector',
                                         date       = date,
                                         sensor     = self.plugin["sensor"],
                                         interface  = self.plugin["interface"],
                                         plugin_id  = self.plugin["id"],
                                         plugin_sid = sid,
                                         priority   = priority,
                                         protocol   = protocol,
                                         src_ip     = src_ip,
                                         src_port   = src_port,
                                         dst_ip     = dst_ip,
                                         dst_port   = dst_port)

                    except IndexError: 
                        pass
                    except ValueError:
                        util.debug (__name__, 
                                    "eventEntryName %s unknown" % name, 
                                    "**", "RED");
        fd.close()

